# Proehl.us Infrastructure
This playbook manages the proehl.us infrastructure, which provides web hosting for proehl.us, as well as proehl family domains.

## Physical Server Setup
We could probably automate this, but it's easy enough to ensure that the following servers are created manually:
  - DigitalOcean
    - dweb-d10-ca-1.proehl.us: basic shared CPU droplet, hosted in SFO-3, running debian 10

## Initial Setup
  - Ensure ~/.ssh/proehlus_ansible_ed25519 key exists
  - Ensure that .ansible_vault_pass exists and has a valid password to decrypt the vaults when the play runs
  - Pull required roles from Ansible Galaxy: `ansible-galaxy role install -r requirements.yml`

Initial setup of a server will require running with `--ask-pass -e 'ansible_port=22'` in order to connect on the default SSH port, deploy the expected SSH keys, change the SSH
port, and restart SSH. (If the server had the proehlus_ansible_ed25519 key deployed to it as part of creation the --ask-pass may be unneeded)
Future connections will be key-only as password login will be disabled. Setting up a new server may require `--limit host` in addition to the above, in order to make the changes
just to the new server.
Before being able to run the plays on a new server with `--ask-pass` you will need to SSH into it manually first, or otherwise ensure that the SSH host key is considered accepted.

## Upating
Run the playbook with the `--tags update` to run server updates.

Note that applications deployed to these servers should be resilient and expect the server to be restarted underneath them without warning.



## Notes on migrating the existing proehlus jitsi/peertube servers to being on a server managed by ansible
docker-jitsi-meet docker-compose.yml

frontend:
       labels:
            - "traefik.enable=true"
            - "traefik.http.middlewares.jitsi-https-only.redirectscheme.scheme=https"
            - "traefik.http.routers.jitsi-http.middlewares=jitsi-https-only"
            - "traefik.http.routers.jitsi-http.rule=Host(`meet.proehl.us`)"
            - "traefik.http.routers.jitsi-http.entrypoints=web"
            - "traefik.http.routers.jitsi.rule=Host(`meet.proehl.us`)"
            - "traefik.http.routers.jitsi.entrypoints=websecure"
            - "traefik.http.routers.jitsi.tls=true"
            - "traefik.http.routers.jitsi.tls.certresolver=myresolver"
            - "traefik.http.routers.jitsi.tls.domains[0].main=meet.proehl.us"
            #- "traefik.http.routers.jitsi.tls.domains[0].sans=*.meet.proehl.us"
            - "traefik.docker.network=traefik_gateway"
        networks:
            meet.jitsi:
                aliases:
                    - ${XMPP_DOMAIN}
            traefik_gateway: {}


# Custom network so all services can communicate using a FQDN
networks:
    meet.jitsi:
    traefik_gateway:
        external: true


MORE PRECISELY:
diff --git a/docker-compose.yml b/docker-compose.yml
index 112b86c..1541191 100644
--- a/docker-compose.yml
+++ b/docker-compose.yml
@@ -38,10 +38,25 @@ services:
             - JIBRI_RECORDER_USER
             - JIBRI_RECORDER_PASSWORD
             - ENABLE_RECORDING
+        labels:
+            - "traefik.enable=true"
+            - "traefik.http.middlewares.jitsi-https-only.redirectscheme.scheme=https"
+            - "traefik.http.routers.jitsi-http.middlewares=jitsi-https-only"
+            - "traefik.http.routers.jitsi-http.rule=Host(`meet.proehl.us`)"
+            - "traefik.http.routers.jitsi-http.entrypoints=web"
+            - "traefik.http.routers.jitsi.rule=Host(`meet.proehl.us`)"
+            - "traefik.http.routers.jitsi.entrypoints=websecure"
+            - "traefik.http.routers.jitsi.tls=true"
+            - "traefik.http.routers.jitsi.tls.certresolver=myresolver"
+            - "traefik.http.routers.jitsi.tls.domains[0].main=meet.proehl.us"
+            #- "traefik.http.routers.jitsi.tls.domains[0].sans=*.meet.proehl.us"
+            - "traefik.docker.network=traefik_gateway"
         networks:
             meet.jitsi:
                 aliases:
                     - ${XMPP_DOMAIN}
+            traefik_gateway: {}
+
 
     # XMPP server
     prosody:
@@ -161,7 +176,10 @@ services:
             - prosody
         networks:
             meet.jitsi:
+            default:
 
 # Custom network so all services can communicate using a FQDN
 networks:
     meet.jitsi:
+    traefik_gateway:
+        external: true

